@@ -110,8 +110,8 @@ static void im_ssl_accept(nx_module_t *module)
     apr_socket_t *sock;
     apr_sockaddr_t *sa;
     char *ipstr;
-    nx_module_input_t *input;
-    SSL *ssl;
+    nx_module_input_t *input = NULL;
+    SSL *ssl = NULL;
     apr_pool_t *pool = NULL;
     apr_status_t rv;
     nx_exception_t e;
@@ -170,15 +170,20 @@ static void im_ssl_accept(nx_module_t *module)
 		
 	    CHECKERR_MSG(apr_socket_data_set(sock, input, "input", NULL),
 			 "couldn't set data on socket");
-	    NX_DLIST_INSERT_TAIL(imconf->connections, input, link);
-	    nx_module_input_data_set(input, "recv_from_str", ipstr);
 	    
 	    nx_module_pollset_add_socket(module, sock, APR_POLLIN | APR_POLLHUP);
 	    log_info("SSL connection accepted from %s:%u", ipstr, sa->port);
+
+	    nx_module_input_data_set(input, "recv_from_str", ipstr);
+	    NX_DLIST_INSERT_TAIL(imconf->connections, input, link);
 	}
     }
     catch(e)
     {
+	if (ssl != NULL)
+	{
+	    nx_ssl_destroy(&ssl);
+	}
 	apr_pool_destroy(pool);
 	rethrow(e);
     }
@@ -577,6 +582,7 @@ static void im_ssl_write(nx_module_t *module, nx_event_t *event)
 		 "couldn't get input data from socket");
     ASSERT(input != NULL);
     ssl = (SSL *) nx_module_input_data_get(input, "ssl");
+
     ASSERT(ssl != NULL);
 
     if ( !SSL_is_init_finished(ssl) )
